# This -*- perl -*- script writes the Makefile for libspace-perl
# $Id: //depot/isms/SpaceKit/blocks.perl/Makefile.PL#3 $

require 5.004;
use strict;

#--- Configuration section ---

my @programs_to_install = qw();
my @request_aliases     = qw();

#--- End Configuration - You should not have to change anything below this line


# Allow us to suppress all program installation with the -n (library only)
# option.  This is for those that don't want to mess with the configuration
# section of this file.
use Getopt::Std;
use vars qw($opt_n);
unless (getopts("n")) {
    die "Usage: $0 [-n]\n";
}
@programs_to_install = () if $opt_n || grep /^LIB=/, @ARGV;


# Check for non-standard modules that are used by this library.
$| = 1;
my $missing_modules = 0;

print "Checking for Data::Dumper ..";
eval {
    require Data::Dumper;
};
if ($@) {
    print " failed\n";
    $missing_modules++;
    print <<EOT;
$@
The Data::Dumper is needed for debugging purposes only.

EOT
    sleep(2);  # Don't hurry too much
} else {
    print " ok\n";
}

print "Checking for Date::Format ..";
eval {
    require Date::Format;
};
if ($@) {
    print " failed\n";
    $missing_modules++;
    print <<EOT;
$@
The Date::Format is needed to parse and format date values.

EOT
    sleep(2);  # Don't hurry too much
} else {
    print " ok\n";
}

print "Checking for Digest::MD5 ..";
eval {
    require Digest::MD5;
};
if ($@) {
    print " failed\n";
    $missing_modules++;
    print <<EOT;
$@
The Digest::MD5 library is needed if you want to be able use the
experimental "Digest Access Authentication" scheme.  Since very few
servers implement this authentication scheme, you should normally not
worry too much about this.

EOT
} else {
    print " ok\n";
}

print "Checking for MIME::Lite ..";
eval {
    require MIME::Lite;
};
if ($@) {
    print " failed\n";
    $missing_modules++;
    print <<EOT;
$@
The MIME::Lite module is needed to generate MIME mail messages.

EOT
    sleep(2);  # Don't hurry too much
} else {
    print " ok\n";
}

print "Checking for MIME::Parser ..";
eval {
    require MIME::Parser;
};
if ($@) {
    print " failed\n";
    $missing_modules++;
    print <<EOT;
$@
The MIME::Parser module is needed to generate and parse MIME content.

EOT
    sleep(2);  # Don't hurry too much
} else {
    print " ok\n";
}

print "Checking for MIME::Base64 ..";
eval {
    require MIME::Base64;
};
if ($@) {
    print " failed\n";
    $missing_modules++;
    print <<EOT;
$@
The MIME::Base64 module is needed to encode/decode MIME base64 data.

EOT
    sleep(2);  # Don't hurry too much
} else {
    print " ok\n";
}

print "Checking for Time::HiRes ..";
eval {
    require Time::HiRes;
};
if ($@) {
    print " failed\n";
    $missing_modules++;
    print <<EOT;
$@
The Time::HiRes module is needed for higher precision timer support.

EOT
    sleep(2);  # Don't hurry too much
} else {
    print " ok\n";
}

print "Checking for XML::Parser..";
eval {
    require XML::Parser::Expat;
};
if ($@) {
    print " failed\n";
    $missing_modules++;
    print <<EOT;
$@
The XML::Parser module is needed to parse XML data and files.

EOT
    sleep(2);  # Don't hurry too much
} else {
    print " ok\n";
}

print <<EOT if $missing_modules;
The missing modules can be obtained from CPAN.  Visit
<URL:http://www.perl.com/CPAN/> to find a CPAN site near you.

EOT


# Ok, now it is time to really generate the Makefile
use ExtUtils::MakeMaker;

WriteMakefile(
   NAME          => 'libspace-perl',
   VERSION_FROM  => 'lib/Space.pm',
   PL_FILES      => { map {("bin/$_.PL" => "bin/$_")} @programs_to_install },
   EXE_FILES     => [ map {"bin/$_"} @programs_to_install ],
   PREREQ_PM     => { 
                      'Date::Format'     => 0,
                      'Digest::MD5'      => "2.09",
                      'IO::Scalar'       => 0,
                      'MIME::Lite'       => "1.135",
                      'MIME::Parser'     => 0,
                      'MIME::Base64'     => 0,
                      'Time::HiRes'      => "01.20",
                      'XML::Parser'      => "2.27",
                     },
   'clean'       => { FILES => '$(EXE_FILES)' },
   'dist'        => { COMPRESS => 'gzip -9f', SUFFIX => 'gz', },
);



package MY;

sub postamble
{
}

# What happens when we say 'make test'
sub test
{
    q(
TEST_VERBOSE=0

test: all
	$(FULLPERL) t/TEST $(TEST_VERBOSE)

);
}


# Determine things that should *not* be installed
sub libscan
{
    my($self, $path) = @_;
    return '' if $path =~ m/.(pl|dtd|sgml)$/;
    return '' if $path =~ m:\bCVS/:;
    return '' if $path =~ m/~$/;
    $path;
}

# Pass libspace-perl version number to pod2man
sub manifypods
{
    my $self = shift;
    my $ver = $self->{VERSION} || "";
    local($_) = $self->SUPER::manifypods(@_);
    s/pod2man\s*$/pod2man --release libspace-perl-$ver/m;
    $_;
}
