#
#  file: Profile/null.pm
#  auth: brad burdick (bburdick@invisible.net)
#  desc: NULL profile support
#

#
# Copyright (c) 2000, Invisible Worlds, Inc. All rights reserved.
#
# The contents of this file are subject to the Blocks Public License (the 
# "License"); you may not use this file except in compliance with the License. 
# You may obtain a copy of the License at http://www.invisible.net/
#
# Software distributed under the License is distributed on an "AS IS" basis, 
# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for 
# the specific language governing rights and limitations under the License.
#

# who am i?
package Profile::null;

# version of perl we expect
require 5.004;

use strict;
use Carp;

use Exporter;
use vars qw (@ISA @EXPORT_OK $VERSION);

@ISA       = qw(Exporter);
@EXPORT_OK = qw();

# current module version
my $Id =<<'EoI';
# $Id: //depot/isms/SpaceKit/blocks.perl/examples/server/lib/Profile/null.pm#10 $
EoI
my $RELEASE = sprintf("%d", $Id =~ /^# \$Id: .*#(\d+)/);

$VERSION = "1.0";


# additional modules we use


use Space::Log;


# other global vars
use vars qw($debug);


# debug mode?
$debug = 0;


#
# state variables
#
# log:   object for logging package
# echoP: true if we're echoing
#



#
# null profile boot protocol (run-time bootable?)
#
sub boot {
	my $log = shift;

	# clear global error indicator
	$! = 0;

	# always bootable
	0;
}


#
# null profile info
#
sub info {
	my $log = shift;

	return [ 0,  # profile provides transport security? (0 or 1)
           [   # supported profile identities (an XML DTD or URI)
	           "http://xml.resource.org/profiles/NULL/ECHO",
	           "http://xml.resource.org/profiles/NULL/SINK"
	         ],
	         {   # public methods of this profile
	           bootV => \&Profile::null::boot,
	           initV => \&Profile::null::init,
	           exchV => \&Profile::null::exch,
	           finV  => \&Profile::null::fin
	         }
	       ];
}


#
# null profile initialisation
#
sub init {
	my $log     = shift;
	my $serverD = shift;
	my $clientA = shift;
	my $upcallV = shift;
	my $uri     = shift;

	return { log => $log, echoP => ($uri eq "http://xml.resource.org/profiles/NULL/ECHO") ? 1 : 0 };
}


#
# null profile finalisation
#
sub fin {
	my $token  = shift;
	my $status = shift;

	0;
}


#
# null profile data/message exchange
#
sub exch {
	my $token = shift;
	my $data  = shift;

	$token->{log}->entry("DEBUG", "null::exch", "echo: ($token->{echoP}),
	            data: ($data)")
		if ($debug > 1);

	return ($token->{echoP}) ? $data : "<null />";
}


#
# library version info
#
sub version {
	return __PACKAGE__ . " " . $VERSION . "r" . $RELEASE;
}


# keep require happy -- DO NOT REMOVE
1;

__END__

